package io.dcloud.feature.weex.adapter.webview;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.AlertDialog.Builder;
import android.content.ComponentName;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.DialogInterface.OnCancelListener;
import android.content.DialogInterface.OnClickListener;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.net.Uri;
import android.net.http.SslError;
import android.os.Handler;
import android.os.Message;
import android.os.Build.VERSION;
import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import android.webkit.JavascriptInterface;
import android.webkit.JsPromptResult;
import android.webkit.PermissionRequest;
import android.webkit.SslErrorHandler;
import android.webkit.ValueCallback;
import android.webkit.WebChromeClient;
import android.webkit.WebResourceError;
import android.webkit.WebResourceRequest;
import android.webkit.WebResourceResponse;
import android.webkit.WebSettings;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.webkit.GeolocationPermissions.Callback;
import android.webkit.WebChromeClient.CustomViewCallback;
import android.webkit.WebChromeClient.FileChooserParams;
import android.widget.FrameLayout;
import android.widget.FrameLayout.LayoutParams;
import androidx.annotation.Nullable;
import androidx.annotation.RequiresApi;
import androidx.core.content.FileProvider;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.JSONObject;
import com.dcloud.android.widget.DCWebViewProgressBar;
import com.taobao.weex.ui.view.IWebView.OnErrorListener;
import com.taobao.weex.ui.view.IWebView.OnMessageListener;
import com.taobao.weex.ui.view.IWebView.OnPageListener;
import com.taobao.weex.utils.WXLogUtils;
import io.dcloud.base.R.string;
import io.dcloud.common.DHInterface.IActivityDelegate;
import io.dcloud.common.DHInterface.IActivityHandler;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.ui.FileChooseDialog;
import io.dcloud.common.adapter.ui.webview.WebViewFactory;
import io.dcloud.common.adapter.util.PermissionUtil;
import io.dcloud.common.adapter.util.PermissionUtil.Request;
import io.dcloud.common.ui.blur.AppEventForBlurManager;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.feature.weex.WeexInstanceMgr;
import io.dcloud.feature.weex.adapter.webview.IDCWebView;
import io.dcloud.feature.weex.adapter.webview.WXDCWeb;
import io.dcloud.feature.weex.adapter.webview.video.FullscreenHolder;
import io.src.dcloud.adapter.DCloudAdapterUtil;
import java.io.File;
import java.lang.ref.WeakReference;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;

public class DCWXWebView implements IDCWebView {

   private Context mContext;
   private String mOrigin;
   private WebView mWebView;
   private FrameLayout mRootView;
   private boolean mShowLoading = true;
   private Handler mMessageHandler;
   private static final int POST_MESSAGE = 1;
   private static final int POST_MESSAGE_TO_CONTROL = 2;
   private static final String BRIDGE_NAME = "__dcloud_weex_";
   private static final int SDK_VERSION = VERSION.SDK_INT;
   private OnErrorListener mOnErrorListener;
   private OnPageListener mOnPageListener;
   private WXDCWeb.OnDCMessageListener mOnMessageListener;
   private DCWebViewProgressBar mWebProgressView;
   private WeakReference mDCWeb;
   public int mProgress = 0;
   private boolean isStart = false;
   private String mDefUserAgent;
   DCWXWebView.DCWXChromeClient chromeClient;
   String mSslType = "refuse";
   private View customView;
   private FrameLayout fullscreenContainer;
   private CustomViewCallback customViewCallback;
   private int defaultSystemUI = 0;


   public DCWXWebView(Context context, String origin, WXDCWeb wxdcWeb) {
      this.mContext = context;
      this.mOrigin = origin;
      this.mDCWeb = new WeakReference(wxdcWeb);
      IWebview iwb = WeexInstanceMgr.self().findWebview(wxdcWeb.getInstance());
      if(iwb != null && iwb.obtainApp() != null) {
         this.mSslType = iwb.obtainApp().obtainConfigProperty("untrustedca");
      }

   }

   public View getView() {
      this.mRootView = new FrameLayout(this.mContext);
      this.mRootView.setBackgroundColor(-1);
      this.mWebView = new WebView(this.mContext) {
         protected void onScrollChanged(int l, int t, int oldl, int oldt) {
            super.onScrollChanged(l, t, oldl, oldt);
            AppEventForBlurManager.onScrollChanged(l, t);
         }
      };
      LayoutParams wvLayoutParams = new LayoutParams(-1, -1);
      wvLayoutParams.gravity = 17;
      this.mWebView.setLayoutParams(wvLayoutParams);
      this.mRootView.addView(this.mWebView);
      this.mWebView.setBackgroundColor(0);
      this.initWebView(this.mWebView);
      this.mMessageHandler = new DCWXWebView.MessageHandler(this, null);
      return this.mRootView;
   }

   public void destroy() {
      if(this.getWebView() != null) {
         this.hideCustomView();
         this.getWebView().setWebViewClient((WebViewClient)null);
         this.getWebView().setWebChromeClient((WebChromeClient)null);
         this.getWebView().removeAllViews();
         this.getWebView().destroy();
         this.mWebView = null;
         this.mDCWeb.clear();
         this.mOnMessageListener = null;
         this.mWebProgressView = null;
         this.mOnPageListener = null;
         this.mOnErrorListener = null;
      }

   }

   public void loadUrl(String url) {
      if(this.getWebView() != null) {
         this.getWebView().loadUrl(url);
      }
   }

   public void loadDataWithBaseURL(String source) {
      if(this.getWebView() != null) {
         this.getWebView().loadDataWithBaseURL(this.mOrigin, source, "text/html", "utf-8", (String)null);
      }
   }

   public void reload() {
      if(this.getWebView() != null) {
         this.getWebView().reload();
      }
   }

   public void goBack() {
      if(this.getWebView() != null) {
         this.getWebView().goBack();
      }
   }

   public void goForward() {
      if(this.getWebView() != null) {
         this.getWebView().goForward();
      }
   }

   public void postMessage(Object msg) {
      if(this.getWebView() != null) {
         try {
            JSONObject e = new JSONObject();
            e.put("type", "message");
            e.put("data", msg);
            this.evaluateJS("javascript:(function () {var initData = " + e.toString() + ";try {var event = new MessageEvent(\'onPostMessage\', initData);window.dispatchEvent(event);} catch (e) {}})();");
         } catch (JSONException var3) {
            throw new RuntimeException(var3);
         }
      }
   }

   public void setShowLoading(boolean shown) {
      this.mShowLoading = shown;
   }

   public void setOnErrorListener(OnErrorListener listener) {
      this.mOnErrorListener = listener;
   }

   public void setOnPageListener(OnPageListener listener) {
      this.mOnPageListener = listener;
   }

   public void setOnMessageListener(OnMessageListener listener) {
   }

   public void onActivityResult(int requestCode, int resultCode, Intent data) {
      if(this.chromeClient != null) {
         this.chromeClient.onResult(requestCode, resultCode, data);
      }

   }

   public void setOnDCMessageListener(WXDCWeb.OnDCMessageListener listener) {
      this.mOnMessageListener = listener;
   }

   private void showWebView(boolean shown) {
      this.mWebView.setVisibility(shown?0:4);
   }

   @Nullable
   public WebView getWebView() {
      return this.mWebView;
   }

   public void setUserAgent(String ua, boolean overwrite) {
      if(this.mWebView != null) {
         WebSettings settings = this.mWebView.getSettings();
         if(!overwrite) {
            if(TextUtils.isEmpty(this.mDefUserAgent)) {
               this.mDefUserAgent = settings.getUserAgentString();
            }

            ua = ua + this.mDefUserAgent + " " + ua;
         }

         settings.setUserAgentString(ua);
      }

   }

   private void initWebView(WebView wv) {
      WebSettings settings = wv.getSettings();
      WebViewFactory.openJSEnabled(settings, (IApp)null);
      settings.setAppCacheEnabled(true);
      settings.setUseWideViewPort(true);
      settings.setDomStorageEnabled(true);
      settings.setSupportZoom(false);
      settings.setAllowFileAccess(false);
      settings.setBuiltInZoomControls(false);
      settings.setAllowContentAccess(true);
      settings.setSavePassword(false);
      if(VERSION.SDK_INT >= 21) {
         settings.setMixedContentMode(0);
      }

      wv.removeJavascriptInterface("searchBoxJavaBridge_");
      wv.removeJavascriptInterface("accessibilityTraversal");
      wv.removeJavascriptInterface("accessibility");
      WebViewFactory.setFileAccess(settings, true);
      settings.setDefaultTextEncodingName("GB2312");
      wv.setWebViewClient(new WebViewClient() {
         public boolean shouldOverrideUrlLoading(WebView view, String url) {
            if(!PdrUtil.isDeviceRootDir(url) && !PdrUtil.isNetPath(url) && !url.startsWith("file://")) {
               try {
                  Intent e;
                  if(url.startsWith("intent://")) {
                     e = Intent.parseUri(url, 1);
                     e.addCategory("android.intent.category.BROWSABLE");
                     e.setComponent((ComponentName)null);
                     if(VERSION.SDK_INT >= 15) {
                        e.setSelector((Intent)null);
                     }

                     List resolves = DCWXWebView.this.mContext.getPackageManager().queryIntentActivities(e, 0);
                     if(resolves.size() > 0) {
                        Activity activity = (Activity)DCWXWebView.this.mContext;
                        activity.startActivityIfNeeded(e, -1);
                     }
                  } else {
                     e = new Intent("android.intent.action.VIEW", Uri.parse(url));
                     e.setFlags(268435456);
                     DCWXWebView.this.mContext.startActivity(e);
                  }
               } catch (Exception var6) {
                  var6.printStackTrace();
               }

               return true;
            } else {
               return false;
            }
         }
         public void onPageStarted(WebView view, String url, Bitmap favicon) {
            super.onPageStarted(view, url, favicon);
            WXLogUtils.v("tag", "onPageStarted " + url);
            if(DCWXWebView.this.mOnPageListener != null) {
               DCWXWebView.this.mOnPageListener.onPageStart(url);
            }

         }
         public void onPageFinished(WebView view, String url) {
            super.onPageFinished(view, url);
            WXLogUtils.v("tag", "onPageFinished " + url);
            if(DCWXWebView.this.isStart) {
               DCWXWebView.this.isStart = false;
               if(DCWXWebView.this.mWebProgressView != null) {
                  DCWXWebView.this.mWebProgressView.finishProgress();
               }
            }

            if(DCWXWebView.this.mOnPageListener != null) {
               DCWXWebView.this.mOnPageListener.onPageFinish(url, view.canGoBack(), view.canGoForward());
            }

         }
         public void onReceivedError(WebView view, WebResourceRequest request, WebResourceError error) {
            super.onReceivedError(view, request, error);
            if(DCWXWebView.this.mOnErrorListener != null) {
               DCWXWebView.this.mOnErrorListener.onError("error", "page error");
            }

         }
         public void onReceivedHttpError(WebView view, WebResourceRequest request, WebResourceResponse errorResponse) {
            super.onReceivedHttpError(view, request, errorResponse);
            if(DCWXWebView.this.mOnErrorListener != null) {
               DCWXWebView.this.mOnErrorListener.onError("error", "http error");
            }

         }
         public void onReceivedSslError(WebView view, final SslErrorHandler handler, final SslError error) {
            if(PdrUtil.isEquals(DCWXWebView.this.mSslType, "refuse")) {
               handler.cancel();
            } else if(PdrUtil.isEquals(DCWXWebView.this.mSslType, "warning")) {
               Context context = view.getContext();
               final AlertDialog ad = (new Builder(context)).create();
               ad.setIcon(17301601);
               ad.setTitle(string.dcloud_common_safety_warning);
               ad.setCanceledOnTouchOutside(false);
               String url = null;
               if(VERSION.SDK_INT >= 14) {
                  url = error.getUrl();
               }

               String msg = context.getString(string.dcloud_common_certificate_continue);
               if(!TextUtils.isEmpty(url)) {
                  msg = url + "\n" + msg;
               }

               ad.setMessage(msg);
               OnClickListener listener = new OnClickListener() {
                  public void onClick(DialogInterface dialog, int which) {
                     if(which == -2) {
                        ad.cancel();
                        ad.dismiss();
                     } else if(which == -3) {
                        error.getCertificate().getIssuedBy();
                     } else if(which == -1) {
                        WebViewFactory.setSslHandlerState(handler, 1);
                        ad.dismiss();
                     }

                  }
               };
               ad.setButton(-2, context.getResources().getString(17039360), listener);
               ad.setButton(-1, context.getResources().getString(17039370), listener);
               ad.show();
            } else {
               WebViewFactory.setSslHandlerState(handler, 1);
            }

            if(DCWXWebView.this.mOnErrorListener != null) {
               DCWXWebView.this.mOnErrorListener.onError("error", "ssl error");
            }

         }
      });
      this.chromeClient = new DCWXWebView.DCWXChromeClient(null);
      wv.setWebChromeClient(this.chromeClient);
      if(VERSION.SDK_INT > 18) {
         wv.addJavascriptInterface(new Object() {
            @JavascriptInterface
            public void postMessage(String message) {
               DCWXWebView.this.onMessage(message, 1);
            }
            @JavascriptInterface
            public void postMessageToService(String message) {
               DCWXWebView.this.onMessage(message, 2);
            }
         }, "__dcloud_weex_");
      }

   }

   private void startWebProgress() {
      if(this.mDCWeb.get() != null && ((WXDCWeb)this.mDCWeb.get()).getHostView() != null) {
         if(this.mDCWeb.get() == null || ((WXDCWeb)this.mDCWeb.get()).getWebStyles() == null || ((WXDCWeb)this.mDCWeb.get()).getWebStyles().getBooleanValue("isProgress")) {
            String url = this.getWebView().getUrl();
            if(!TextUtils.isEmpty(url) && !url.startsWith("file")) {
               if(this.mWebProgressView == null) {
                  this.mWebProgressView = new DCWebViewProgressBar(this.mWebView.getContext());
               }

               String colorStr = "#00FF00";
               if(((WXDCWeb)this.mDCWeb.get()).getWebStyles().containsKey("progressColor")) {
                  colorStr = ((WXDCWeb)this.mDCWeb.get()).getWebStyles().getString("progressColor");
               }

               int colorInt = PdrUtil.stringToColor(colorStr);
               int heightInt = PdrUtil.convertToScreenInt("2px", this.mWebView.getMeasuredWidth(), 0, this.mWebView.getScale());
               this.mWebProgressView.setColorInt(colorInt);
               this.mWebProgressView.setVisibility(0);
               this.mWebProgressView.setAlphaInt(255);
               if(this.mWebProgressView.getParent() == null) {
                  this.mRootView.addView(this.mWebProgressView, new android.view.ViewGroup.LayoutParams(-1, heightInt));
               }

               this.mWebProgressView.startProgress();
            }
         }
      }
   }

   private void onMessage(String message, int type) {
      if(message != null && this.mOnMessageListener != null) {
         Object m = null;

         try {
            m = JSON.parse(message);
         } catch (Exception var5) {
            m = message;
         }

         Message threadMessage = new Message();
         threadMessage.what = type;
         threadMessage.obj = m;
         this.mMessageHandler.sendMessage(threadMessage);
      }

   }

   private void evaluateJS(String jsStr) {
      if(SDK_VERSION < 19) {
         this.mWebView.loadUrl(jsStr);
      } else {
         this.mWebView.evaluateJavascript(jsStr, (ValueCallback)null);
      }

   }

   private void showCustomView(View view, CustomViewCallback callback) {
      if(this.customView != null) {
         callback.onCustomViewHidden();
      } else {
         if(this.mContext != null && this.mContext instanceof Activity) {
            Activity activityT = (Activity)this.mContext;
            FrameLayout activityContentView = null;
            IActivityHandler iActivityHandler = DCloudAdapterUtil.getIActivityHandler(activityT);
            if(iActivityHandler != null) {
               activityContentView = iActivityHandler.obtainActivityContentView();
               iActivityHandler.closeSideBar();
               iActivityHandler.setSideBarVisibility(8);
            } else if(activityT instanceof IActivityDelegate) {
               activityContentView = ((IActivityDelegate)activityT).obtainActivityContentView();
            }

            this.mWebView.setVisibility(8);
            this.fullscreenContainer = new FullscreenHolder(this.mContext);
            LayoutParams lp = new LayoutParams(-1, -1);
            this.fullscreenContainer.addView(view, lp);
            activityContentView.addView(this.fullscreenContainer, lp);
            this.customView = view;
            this.setStatusBarVisibility(activityT, false);
            this.customViewCallback = callback;
         }

      }
   }

   private void hideCustomView() {
      if(this.customView != null) {
         if(this.mContext != null && this.mContext instanceof Activity) {
            Activity activityT = (Activity)this.mContext;
            this.setStatusBarVisibility(activityT, true);
            if(this.fullscreenContainer.getParent() != null) {
               ((ViewGroup)this.fullscreenContainer.getParent()).removeView(this.fullscreenContainer);
               this.fullscreenContainer.removeAllViews();
            }

            this.fullscreenContainer = null;
            this.customView = null;
            if(this.customViewCallback != null) {
               this.customViewCallback.onCustomViewHidden();
               this.customViewCallback = null;
            }

            this.mWebView.setVisibility(0);
         }

      }
   }

   private void setStatusBarVisibility(Activity activity, boolean visible) {
      if(visible) {
         activity.getWindow().getDecorView().setSystemUiVisibility(this.defaultSystemUI);
      } else {
         this.defaultSystemUI = activity.getWindow().getDecorView().getSystemUiVisibility();
         activity.getWindow().getDecorView().setSystemUiVisibility(5894);
      }

   }


   private class DCWXChromeClient extends WebChromeClient {

      FileChooseDialog dialog;
      ValueCallback mUploadMessage;
      ValueCallback mUploadMessage21Level;


      private DCWXChromeClient() {
      }

      public void onPermissionRequest(PermissionRequest request) {
         request.grant(request.getResources());
      }

      public void onProgressChanged(WebView view, int newProgress) {
         super.onProgressChanged(view, newProgress);
         DCWXWebView.this.mProgress = newProgress;
         if(!DCWXWebView.this.isStart && DCWXWebView.this.mProgress < 100) {
            DCWXWebView.this.startWebProgress();
            DCWXWebView.this.isStart = true;
         }

         if(DCWXWebView.this.mProgress >= 100 && DCWXWebView.this.isStart) {
            DCWXWebView.this.isStart = false;
            if(DCWXWebView.this.mWebProgressView != null) {
               DCWXWebView.this.mWebProgressView.finishProgress();
            }
         }

         WXLogUtils.v("tag", "onPageProgressChanged " + newProgress);
      }

      public void onReceivedTitle(WebView view, String title) {
         super.onReceivedTitle(view, title);
         if(DCWXWebView.this.mOnPageListener != null) {
            DCWXWebView.this.mOnPageListener.onReceivedTitle(view.getTitle());
         }

      }

      public boolean onJsPrompt(WebView view, String url, String text, String defaultValue, JsPromptResult result) {
         return super.onJsPrompt(view, url, text, defaultValue, result);
      }

      public void onGeolocationPermissionsShowPrompt(final String origin, final Callback callback) {
         if(DCWXWebView.this.mContext instanceof Activity) {
            PermissionUtil.usePermission((Activity)DCWXWebView.this.mContext, "dc_weexsdk", "LOCATION", 2, new Request() {
               public void onGranted(String streamPerName) {
                  callback.invoke(origin, true, false);
               }
               public void onDenied(String streamPerName) {
                  callback.invoke(origin, false, false);
               }
            });
         } else {
            super.onGeolocationPermissionsShowPrompt(origin, callback);
         }

      }

      @RequiresApi(
         api = 21
      )
      public boolean onShowFileChooser(WebView webView, ValueCallback filePathCallback, FileChooserParams fileChooserParams) {
         this.openFileChooserLogic(webView, (ValueCallback)null, filePathCallback, fileChooserParams.getAcceptTypes() != null?fileChooserParams.getAcceptTypes()[0]:null, "");
         return true;
      }

      private void openFileChooserLogic(final WebView webView, final ValueCallback uploadMsg, final ValueCallback uploadMsg21Level, final String acceptType, final String capture) {
         if(DCWXWebView.this.mContext != null) {
            PermissionUtil.usePermission((Activity)DCWXWebView.this.mContext, "dc_weexsdk", "STORAGE", 2, new Request() {
               public void onGranted(String perName) {
                  DCWXChromeClient.this.showOpenFileChooser(webView, uploadMsg, uploadMsg21Level, acceptType, capture);
               }
               public void onDenied(String perName) {
               }
            });
         }
      }

      private void showOpenFileChooser(WebView webView, ValueCallback uploadMsg, ValueCallback uploadMsg21Level, String acceptType, String capture) {
         this.mUploadMessage = uploadMsg;
         this.mUploadMessage21Level = uploadMsg21Level;
         Intent i = new Intent("android.intent.action.GET_CONTENT");
         i.addCategory("android.intent.category.OPENABLE");
         if(!PdrUtil.isEmpty(acceptType)) {
            i.setType(acceptType);
         } else {
            i.setType("*/*");
         }

         this.dialog = new FileChooseDialog(webView.getContext(), (Activity)webView.getContext(), i);

         try {
            this.dialog.show();
            this.dialog.setOnCancelListener(new OnCancelListener() {
               public void onCancel(DialogInterface dialog) {
                  try {
                     if(DCWXChromeClient.this.mUploadMessage21Level != null) {
                        DCWXChromeClient.this.mUploadMessage21Level.onReceiveValue((Object)null);
                     } else if(DCWXChromeClient.this.mUploadMessage != null) {
                        DCWXChromeClient.this.mUploadMessage.onReceiveValue((Object)null);
                     }
                  } catch (Exception var3) {
                     ;
                  }

               }
            });
         } catch (Exception var8) {
            ;
         }

      }

      public void onResult(int requestCode, int resultCode, Intent data) {
         if(this.dialog != null) {
            this.dialog.dismiss();
            if(resultCode != 0) {
               Uri value = null;
               if(requestCode == 1) {
                  if(data == null) {
                     if(this.mUploadMessage21Level != null) {
                        this.mUploadMessage21Level.onReceiveValue((Object)null);
                     } else if(this.mUploadMessage != null) {
                        this.mUploadMessage.onReceiveValue((Object)null);
                     }

                     this.dialog = null;
                     return;
                  }

                  value = data.getData();
                  if(value != null && VERSION.SDK_INT < 29 && "content".equals(value.getScheme())) {
                     Cursor uris = DCWXWebView.this.mContext.getContentResolver().query(value, new String[]{"_data"}, (String)null, (String[])null, (String)null);
                     if(uris != null) {
                        if(uris.moveToFirst()) {
                           try {
                              int u = uris.getColumnIndexOrThrow("_data");
                              if(u > -1) {
                                 String uriString = uris.getString(u);
                                 value = Uri.parse(uriString);
                                 if(PdrUtil.isEmpty(value.getScheme())) {
                                    String scheme = uriString.startsWith("/")?"file://":"file:///";
                                    value = Uri.parse(scheme + uriString);
                                 }
                              }
                           } catch (Exception var9) {
                              ;
                           }
                        }

                        uris.close();
                     }
                  }
               } else if(requestCode == 2 && this.dialog != null && this.dialog.uris != null) {
                  Iterator uris1 = this.dialog.uris.iterator();

                  while(uris1.hasNext()) {
                     File u1 = (File)uris1.next();
                     if(u1.exists()) {
                        value = FileProvider.getUriForFile(DCWXWebView.this.mContext, DCWXWebView.this.mContext.getPackageName() + ".dc.fileprovider", u1);
                        break;
                     }
                  }
               }

               Uri[] uris2 = null;
               if(value != null) {
                  uris2 = new Uri[]{value};
               }

               if(this.mUploadMessage21Level != null) {
                  this.mUploadMessage21Level.onReceiveValue(uris2);
               } else if(this.mUploadMessage != null) {
                  this.mUploadMessage.onReceiveValue(value);
               }
            } else if(this.mUploadMessage21Level != null) {
               this.mUploadMessage21Level.onReceiveValue((Object)null);
            } else if(this.mUploadMessage != null) {
               this.mUploadMessage.onReceiveValue((Object)null);
            }

            this.dialog = null;
         }
      }

      public void onShowCustomView(View view, CustomViewCallback callback) {
         DCWXWebView.this.showCustomView(view, callback);
      }

      public void onHideCustomView() {
         DCWXWebView.this.hideCustomView();
      }

      // $FF: synthetic method
      DCWXChromeClient(Object x1) {
         this();
      }
   }

   private static class MessageHandler extends Handler {

      private final WeakReference mWv;


      private MessageHandler(DCWXWebView wv) {
         this.mWv = new WeakReference(wv);
      }

      public void handleMessage(Message msg) {
         super.handleMessage(msg);
         HashMap map;
         switch(msg.what) {
         case 1:
            if(this.mWv.get() != null && ((DCWXWebView)this.mWv.get()).mOnMessageListener != null) {
               map = new HashMap();
               map.put("detail", msg.obj);
               ((DCWXWebView)this.mWv.get()).mOnMessageListener.onMessage(map, 1);
            }
            break;
         case 2:
            if(this.mWv.get() != null && ((DCWXWebView)this.mWv.get()).mOnMessageListener != null) {
               map = new HashMap();
               map.put("data", msg.obj);
               ((DCWXWebView)this.mWv.get()).mOnMessageListener.onMessage(map, 2);
            }
         }

      }

      // $FF: synthetic method
      MessageHandler(DCWXWebView x0, Object x1) {
         this(x0);
      }
   }
}
